@@ -44,7 +44,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "1.7.0",
+    VERSIONNUM       => "1.7.1",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -994,7 +994,7 @@ sub get_restore_archivewal_num {
     my $result;
     my $wal_segment_num;
 
-    $result = `$LS -l $archive_dir | $GREP -P \"[0-9A-F]{24}\$\" | $TAIL -1`;
+    $result = `$LS -lH $archive_dir | $GREP -P \"[0-9A-F]{24}\$\" | $TAIL -1`;
     if ($result && $result =~ /.*([0-9A-F]{24})$/){
         $latest_archive_walfile = $1;
         chomp $latest_archive_walfile;
@@ -1086,7 +1086,8 @@ sub check_support_version {
 
     # PostgreSQL がサポート対象バージョンであるかを確認する
     @version_factor = split(/\./, get_pg_version($postgres_path, $exec_user));
-    if (!($version_factor[0] == 9 && $version_factor[1] == 4)){
+    if ($version_factor[0] != 9 ||
+        ($version_factor[1] != 4 && $version_factor[1] != 5)){
             printlog("ERROR", COMMON_MS0037, get_pg_version($postgres_path), $exec_user);
     }
 }
